@@ -4,14 +4,18 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
 #ifndef H5Mmodule_H
 #define H5Mmodule_H
+
 #define H5M_MODULE
-#define H5_MY_PKG     H5M
-#define H5_MY_PKG_ERR H5E_MAP
-#endif
+#define H5_MY_PKG      H5M
+#define H5_MY_PKG_ERR  H5E_MAP
+#define H5_MY_PKG_INIT YES
+
+#endif 
